/*------------------------------------------------------------------------------
-- This file is a part of the QLop Software
-- Copyright (C) 2015, Plasma Physics Laboratory - CNRS
--
-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-------------------------------------------------------------------------------*/
/*-- Author : Alexis Jeandet
-- Mail : alexis.jeandet@member.fsf.org
----------------------------------------------------------------------------*/

#ifndef QLOPDATA_H
#define QLOPDATA_H

#include <QObject>
#include <qcustomplot.h>

typedef struct dataVector
{
  QString name;
  QString unit;
  QVector<QCPData>* data;
}dataVector;

typedef QList<dataVector> QListOfDataVector;


class QLopData : public QObject
{
    Q_OBJECT
public:
#define QLopDataTypeCnt 5
    typedef enum QLopDataType
    {
        Scalar=0,
        Vector=1,
        Matrix=2,
        QCPDataVector=3,
        None=-1,
    }QLopDataType;

    struct QLopDataTypeList_t
    {
        QLopDataType type;
        const char* typeStr;
    };

    static struct QLopDataTypeList_t QLopDataTypeList[];
    explicit QLopData(QObject *parent = 0);
    ~QLopData();
    QString name;
    QString source;
    QString unit;
    QString typeStr()
    {
        for(int i=0;i<QLopDataTypeCnt;i++)
        {
            if(QLopDataTypeList[i].type==this->type)
                return QLopDataTypeList[i].typeStr;
        }
        return "Unknow data type";
    }
    QLopDataType type;
    int ID;
    virtual int size(){return 0;}
signals:
    void dataChanged();
public slots:
private:
};

class QLopQCPDataVector : public QLopData
{
    Q_OBJECT
public:
    explicit QLopQCPDataVector(QObject *parent = 0);
    ~QLopQCPDataVector();
    QVector<QCPData>* data;
    int size(){return data->length();}
signals:
public slots:
private:
};

class QLopQVector : public QLopData
{
    Q_OBJECT
public:
    explicit QLopQVector(QObject *parent = 0);
    ~QLopQVector();
    QVector<double>* data;
    int size(){return data->length();}
signals:
public slots:
private:
};
typedef QList<QLopData*> QLopDataList;


#endif // QLOPDATA_H
